%# BEGIN BPS TAGGED BLOCK {{{
%# 
%# COPYRIGHT:
%# 
%# This software is Copyright (c) 1996-2008 Best Practical Solutions, LLC
%#                                          <jesse@bestpractical.com>
%# 
%# (Except where explicitly superseded by other copyright notices)
%# 
%# 
%# LICENSE:
%# 
%# This work is made available to you under the terms of Version 2 of
%# the GNU General Public License. A copy of that license should have
%# been provided with this software, but in any event can be snarfed
%# from www.gnu.org.
%# 
%# This work is distributed in the hope that it will be useful, but
%# WITHOUT ANY WARRANTY; without even the implied warranty of
%# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%# General Public License for more details.
%# 
%# You should have received a copy of the GNU General Public License
%# along with this program; if not, write to the Free Software
%# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
%# 02110-1301 or visit their web page on the internet at
%# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
%# 
%# 
%# CONTRIBUTION SUBMISSION POLICY:
%# 
%# (The following paragraph is not intended to limit the rights granted
%# to you to modify and distribute this software under the terms of
%# the GNU General Public License and is only of importance to you if
%# you choose to contribute your changes and enhancements to the
%# community by submitting them to Best Practical Solutions, LLC.)
%# 
%# By intentionally submitting any modifications, corrections or
%# derivatives to this work, or any other work intended for use with
%# Request Tracker, to Best Practical Solutions, LLC, you confirm that
%# you are the copyright holder for those contributions and you grant
%# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
%# royalty-free, perpetual, license to use, copy, create derivative
%# works based on those contributions, and sublicense and distribute
%# those contributions and any derivatives thereof.
%# 
%# END BPS TAGGED BLOCK }}}
<& /Admin/Elements/Header, Title => $title  &>
<& /Admin/Elements/UserTabs, 
    id => $id, 
    UserObj => $UserObj,
    current_tab => $current_tab, 
    Title => $title &>

<h2><&|/l&>Queues the user is AdminCc watcher</&></h2>
<ul>
% while ( my $QueueObj = $QueuesObj->Next ) {
%     if ( $QueueObj->IsAdminCc($UserObj->PrincipalId) ) {
<li><a href="<%RT->Config->Get('WebPath')%>/Admin/Queues/People.html?id=<% $QueueObj->Id %>"><% $QueueObj->Name %></a></li>
%     }
% }
</ul>

<h2><&|/l&>Queues the user is Cc watcher</&></h2>
<ul>
% while ( my $QueueObj = $QueuesObj->Next ) {
%     if ( $QueueObj->IsCc($UserObj->PrincipalId) ) {
<li><a href="<%RT->Config->Get('WebPath')%>/Admin/Queues/People.html?id=<% $QueueObj->Id %>"><% $QueueObj->Name %></a></li>
%     }
% }
</ul>


</form>

<%INIT>
my $UserObj = RT::User->new($session{'CurrentUser'});
$UserObj->Load( $id ) || Abort("Couldn't load user '$id'");

my $QueuesObj = RT::Queues->new($session{'CurrentUser'});
$QueuesObj->UnLimit;

my $title = loc("Watched queues of the user [_1]", $UserObj->Name);
my $current_tab = 'Admin/Users/WatchedQueues.html?id='. $id;
$id = $UserObj->Id;

</%INIT>
<%ARGS>
$id     => undef
</%ARGS>
